@@ -1,6 +1,6 @@
 ##---------------------------------------------------------------------------##
 ##  File:
-##	$Id: Config.pm,v 1.6 2002/07/17 21:59:36 ehood Exp $
+##	$Id: Config.pm,v 1.7 2002/09/13 07:24:18 ehood Exp $
 ##  Description:
 ##	POD at end of file.
 ##---------------------------------------------------------------------------##
@@ -138,9 +138,16 @@ get overwritten on software updates.
 
 =head1 VERSION
 
-C<$Id>
+C<$Id: Config.pm,v 1.7 2002/09/13 07:24:18 ehood Exp $>
 
 =head1 AUTHOR
 
 Earl Hood, earl@earlhood.com
 
+This module is part of the mharc archiving system and comes with
+ABSOLUTELY NO WARRANTY and may be copied only under the terms of
+the GNU General Public License, which may be found in the MHArc
+distribution.
+
+=cut
+
